mesh = Mesh.loadFromGeometry('unitsquare');
mesh.refineUniform(1);
fes = FeSpace(mesh, HigherOrderH1Fe(1), 'dirichlet', ':');

%% set problem data
blf = BilinearForm();

ncFes = FeSpace(mesh, LowestOrderL2Fe());
a = FeFunction(ncFes);
trafo = getAffineTransformation(mesh);
n = trafo.n;
f(mesh.coordinates, n)
%b = MeshFunction(mesh, @(x) x)
%b = PiecewiseEvaluable(mesh, @(x, nu) f(x, nu), n);
%a.setData(nodalInterpolation(MeshFunction(mesh, @(x) f(x, n)), ncFes));
%blf.a = a;
%qr = QuadratureRule.ofOrder(max(2, 1), '1D');



% constant that jumps k times by factor of 'size' within the mesh
function val = f(x, n)
    val = zeros(size(x, 1), 1);

    val(strictlyLess(x(1, :), 0.25)) = 1;
    val(strictlyBetween(x(1, :), 0.25, 0.5)) = 2;
    val(strictlyBetween(x(1, :), 0.5, 0.75)) = 3;
    val(strictlyGreater(x(1, :), 0.75)) = 4;

    val(near(x(1, :), 0.25) & strictlyLess(n(1, :),0)) = 1;
    val(near(x(1, :), 0.25) & strictlyGreater(n(1,:),0)) = 2;

    val(near(x(1, :), 0.5) & strictlyLess(n(1, :),0)) = 2;
    val(near(x(1, :), 0.5) & strictlyGreater(n(1, :),0)) = 3;

    val(near(x(1, :), 0.75) & strictlyLess(n(1, :),0)) = 3;
    val(near(x(1, :), 0.75) & strictlyGreater(n(1, :),0)) = 4;
end

function isNear = near(x, y, tol)
if nargin < 3
    tol = 1e4 * eps;
end

% Check with given tolerance
isNear = abs(x - y) < tol;
end

function isGreater = strictlyGreater(x, y, tol)
if nargin < 3
    tol = 1e4 * eps;
end

% Check with given tolerance
isGreater = abs(x - y) < tol;
end

function isLess = strictlyLess(x, y, tol)
if nargin < 3
    tol = 1e4 * eps;
end

% Check with given tolerance
isLess = abs(x - y) < tol;
end

function isStrictlyBetween = strictlyBetween(x, y, z, tol)
if nargin < 4
    tol = 1e4 * eps;
end

% Check with given tolerance
isStrictlyBetween = (x - y) > tol & (z - x) > tol;

end





